netapp_ontap.models.node_ha_takeover API documentation
Description: Copyright &copy; 2020 NetApp Inc. All rights reserved.

# Module `netapp_ontap.models.node_ha_takeover`

Copyright © 2020 NetApp Inc. All rights reserved.

## Classes

`class NodeHaTakeoverSchema (*, only: typing.Union = None, exclude: typing.Union = (), many: bool = False, context: typing.Dict = None, load_only: typing.Union = (), dump_only: typing.Union = (), partial: typing.Union = False, unknown: str = None)`

  The fields of the NodeHaTakeover object

  ### Ancestors

  - netapp_ontap.resource.ResourceSchema
  - marshmallow.schema.Schema
  - marshmallow.base.SchemaABC

  ### Class variables

  `failure GET POST PATCH`

    The failure field of the node_ha_takeover.

  `state GET POST PATCH`

    The state field of the node_ha_takeover.

    Valid choices:

    - not_possible
    - not_attempted
    - in_takeover
    - in_progress
    - failed